/*******************************************************************************
 * 
 * jKiwi -- A virtual makeover and hairstyler application
 * Copyright (c) 2007-2008 Dan Mihai Ile, Maria Joao Roque Barbado Leal
 * 
 * This file is part of jKiwi.
 * 
 * jKiwi is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 * 
 * jKiwi is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 *******************************************************************************/

package utils;

import java.io.File;
import java.io.IOException;
import java.util.ResourceBundle;

import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.MessageBox;
import org.eclipse.swt.widgets.Shell;

import core.Loader;

/**
 * This class provides a platform independent help system
 */
//TODO a more complete implementation is needed here
public class HelpWindow {

	private final String HELP_FOLDER = "help";
	private final String HELP_DEFAULT_XML_FOLDER = "C";
	private final String HELP_XML_FILE = "jkiwi.xml";
	
	/**
	 * messages that are to be used by the entire GUI
	 */
	private ResourceBundle messages = Loader.getMessages();
	private final Shell parentShell;

	public HelpWindow(Shell parentShell) {
		this.parentShell = parentShell;
	}

	/**
	 * Open a new help window for this application
	 * Whenever possible the guest operating system help
	 * is used to display the application's help manual
	 */
	public void open() {
		if (System.getProperty("os.name").equalsIgnoreCase("linux")) {
			
			//check for linux desktop name
			String desktopName = System.getProperty("sun.desktop");
			if (desktopName == null) {
				//unable to retrieve the desktop name, possible that sun.desktop system
				//variable is null. No problem, default icons will be used.
				desktopName = ""; //initialize the variable to avoid null exception
			}
			
			//We are in Gnome desktop
			if (desktopName.equalsIgnoreCase("gnome")) {
				String completeXMLFilePath = null;
				
				//by default try to use the installed help, if not available look for it in the apllication folder
				String parentApplicationPath = new File(System.getProperty("program.sourcepath")).getParent();
				File helpDir = new File(parentApplicationPath + File.separator + "gnome" + File.separator + "help" + File.separator + "jkiwi");
				String pathToHelpDirectory = null;
				if (helpDir.exists()) {
					pathToHelpDirectory = helpDir.getAbsolutePath() + File.separator;
				} else {
					pathToHelpDirectory = System.getProperty("program.sourcepath") + HELP_FOLDER + File.separator;
				}
				
				File perfectMatchDirectory = new File(pathToHelpDirectory + messages.getLocale().toString());
				File languageMatchDirectory = new File(pathToHelpDirectory + messages.getLocale().getLanguage());
				
				if (perfectMatchDirectory.exists() && perfectMatchDirectory.isDirectory()) {
					completeXMLFilePath = perfectMatchDirectory.getPath() + File.separator + HELP_XML_FILE;
				} else if (languageMatchDirectory.exists() && languageMatchDirectory.isDirectory()) {
					completeXMLFilePath = languageMatchDirectory.getPath() + File.separator + HELP_XML_FILE;
				} else {
					completeXMLFilePath = pathToHelpDirectory + HELP_DEFAULT_XML_FOLDER + File.separator + HELP_XML_FILE;
				}
				
				//it seems that yelp is unable to open files that contains spaces in path
				if (completeXMLFilePath.contains(" ")) {
					MessageBox mb = new MessageBox(parentShell, SWT.ICON_WARNING);
					mb.setText(messages.getString("HELP_WINDOW_MESSAGE-BOX_PATH_PROBLEM_TITLE"));
					mb.setMessage(messages.getString("HELP_WINDOW_MESSAGE-BOX_PATH_PROBLEM_TEXT") +
							System.getProperty("program.sourcepath").replace(" ", "_"));
					mb.open();
				} else {
					try {
						Runtime.getRuntime().exec(new String[] {"yelp", completeXMLFilePath });
					} catch (IOException e) {
						// TODO Auto-generated catch block
						e.printStackTrace();
					}
				}
			} else { //other linux desktops goes here (kde, etc..)
				//TODO other linux desktop help system
			}
		} else { //other operating systems goes here (Mac OS X, Windows, etc.)
			//TODO other operating system help goes here
		}
	}
}
